@@ -1,7 +1,7 @@
-/* $Id: upnpc.c,v 1.116 2017/04/21 10:20:50 nanard Exp $ */
+/* $Id: upnpc.c,v 1.118 2018/02/22 15:07:17 nanard Exp $ */
 /* Project : miniupnp
  * Author : Thomas Bernard
- * Copyright (c) 2005-2016 Thomas Bernard
+ * Copyright (c) 2005-2018 Thomas Bernard
  * This software is subject to the conditions detailed in the
  * LICENCE file provided in this distribution. */
 
@@ -578,8 +578,8 @@ int main(int argc, char ** argv)
 	}
 #endif
     printf("upnpc : miniupnpc library test client, version %s.\n", MINIUPNPC_VERSION_STRING);
-	printf(" (c) 2005-2016 Thomas Bernard.\n");
-    printf("Go to http://miniupnp.free.fr/ or http://miniupnp.tuxfamily.org/\n"
+	printf(" (c) 2005-2017 Thomas Bernard.\n");
+    printf("Go to http://miniupnp.free.fr/ or https://miniupnp.tuxfamily.org/\n"
 	       "for more information.\n");
 	/* command line processing */
 	for(i=1; i<argc; i++)
@@ -594,7 +594,10 @@ int main(int argc, char ** argv)
 			if(argv[i][1] == 'u')
 				rootdescurl = argv[++i];
 			else if(argv[i][1] == 'm')
+			{
 				multicastif = argv[++i];
+				minissdpdpath = "";	/* Disable usage of minissdpd */
+			}
 			else if(argv[i][1] == 'z')
 			{
 				char junk;
